@@ -68,11 +68,11 @@ class JSObject(object):
 
 class RemotePage(object):
 
-    def __init__(self, name):
+    def __init__(self, path):
         '''
             remote: object used to access remote JS code.
         '''
-        self.name = name
+        self.path = path
         self.document = JSObject('document', self)
         self.window = JSObject('window', self)
         self.alert = JSObject('alert', self)
@@ -80,7 +80,7 @@ class RemotePage(object):
 
     def run(self, command):
         logging.info(('run', [command]))
-        for listener in server.LISTENERS:
+        for listener in server.LISTENERS.get(self.path, []):
             logging.debug(('listener:', listener))
             listener.write_message('$' + command)
 
@@ -95,7 +95,7 @@ class RemotePage(object):
 
         message = '?' + job_id + '=' + command
         logging.info(('message:', [message]))
-        for listener in server.LISTENERS:
+        for listener in server.LISTENERS.get(self.path, []):
             logging.debug(('listener:', listener))
             listener.write_message(message)
 
@@ -111,3 +111,11 @@ class RemotePage(object):
             if job_id in server.RESULTS:
                 del server.RESULTS[job_id]
             raise IOError('Evaluation failed.')
+
+    def register(self, callback, name):
+        'Register a callback on server and on connected clients.'
+        server.CALLBACKS[name] = callback
+        self.run('''
+            window.skink.%s = function(args=[]) {
+                window.skink.call("%s", args);
+            }''' % (name, name))
